from __future__ import annotations

__version__ = "1.0.7"
__license__ = "Açık Kaynak: Open Source, MIT, Apache License 2.0"
__description__ = "Grikod (Gri Kod, Gray Code, Grey Code)"
__author__ = "Mehmet Keçeci"
__url__ = "https://github.com/KuantumBS/grikod"
__dependencies__ = ["python>=3.8"]
